Circuit Provider - Nautobot Documentation

Skip to content

# Providers

A circuit provider is any entity which provides some form of connectivity among locations or organizations within a location. While this obviously includes carriers which offer Internet and private transit service, it might also include Internet exchange (IX) points and even organizations with whom you peer directly. Each circuit within Nautobot must be assigned a provider and a circuit ID which is unique to that provider.

Each provider may be assigned an autonomous system number (ASN), an account number, and contact information.